@@ -3,10 +3,8 @@ import numpy as np
 
 from neurom import COLS
 
-X, Y, Z = 0, 1, 2
 
-
-def point_to_section_segment(neuron, point):
+def point_to_section_segment(neuron, point, rtol=1e-05, atol=1e-08):
     '''Find section and segment that matches the point.
 
     Only the first point found with the *exact* same coordinates as the point argument is considered
@@ -14,6 +12,7 @@ def point_to_section_segment(neuron, point):
     Args:
         neuron (morphio.Morphology): neuron object
         point (point): value of the point to find in the h5 file
+        rtol, atol (floats): precission of np.isclose
 
     Returns:
         Tuple: (NeuroM/MorphIO section ID, point ID) of the point the matches the input coordinates.
@@ -22,9 +21,9 @@ def point_to_section_segment(neuron, point):
 
     for section in neuron.iter():
         points = section.points
-        offset = np.where((points[:, X] == point[COLS.X]) &
-                          (points[:, Y] == point[COLS.Y]) &
-                          (points[:, Z] == point[COLS.Z]))
+        offset = np.where(
+            np.isclose(points[:, COLS.XYZ], point[COLS.XYZ], rtol=rtol, atol=atol).all(axis=1)
+        )
         if offset[0].size:
             return section.id, offset[0][0]
 
