@@ -1,23 +1,16 @@
-import nose.tools as nt
-from pathlib import Path
-
 import mock
 from mock import patch
 
 import morph_tool.loader as tested
 
-DATA = Path(__file__).absolute().parent / "data"
-
 
 def test_ensure_startswith_point():
-    nt.assert_equal(
-        tested._ensure_startswith_point(".ext"),
-        ".ext"
-    )
-    nt.assert_equal(
-        tested._ensure_startswith_point("ext"),
-        ".ext"
-    )
+    assert (
+        tested._ensure_startswith_point(".ext") ==
+        ".ext")
+    assert (
+        tested._ensure_startswith_point("ext") ==
+        ".ext")
 
 
 @patch('morphio.Morphology')
@@ -26,20 +19,17 @@ def test_loader(f_mock):
     loader = tested.MorphLoader('/dir', file_ext='abc', cache_size=1)
     morph1 = loader.get('test')
     # should get cached object now
-    nt.assert_is(
-        loader.get('test'),
-        morph1
-    )
+    assert (
+        loader.get('test') is
+        morph1)
     # options are different => should not get cached object
-    nt.assert_is_not(
-        loader.get('test', options=42),
-        morph1
-    )
+    assert (
+        loader.get('test', options=42) is not
+        morph1)
     # first cached object was evicted from the cache
-    nt.assert_is_not(
-        loader.get('test'),
-        morph1
-    )
+    assert (
+        loader.get('test') is not
+        morph1)
     f_mock.assert_has_calls([
         mock.call('/dir/test.abc'),
         mock.call('/dir/test.abc', 42),
@@ -52,4 +42,4 @@ def test_loader_no_cache(f_mock):
     loader = tested.MorphLoader('/dir', file_ext='abc', cache_size=0)
     loader.get('test')
     loader.get('test')
-    nt.assert_equal(f_mock.call_count, 2)
+    assert f_mock.call_count == 2
